@@ -24,8 +24,11 @@ function cleanup() {
 
 trap cleanup EXIT
 
+EXTRA_TEST_FLAGS="${EXTRA_TEST_FLAGS:=""}"
+MANIFESTS_BASE_DIR="${MANIFESTS_BASE_DIR:=manifests/deploy}"
 METERING_SHORT_TESTS="${METERING_SHORT_TESTS:=false}"
 METERING_REPO_PATH="${METERING_REPO_PATH:=${ROOT_DIR}}"
+METERING_REPO_VERSION="$(basename $(find $MANIFESTS_BASE_DIR -type d | sort -r | head -n 1))"
 METERING_RUN_TESTS_LOCALLY="${METERING_RUN_TESTS_LOCALLY:=false}"
 
 TEST_OUTPUT_PATH="${TEST_OUTPUT_PATH:="$(mktemp -d)/${METERING_NAMESPACE}"}"
@@ -37,13 +40,13 @@ TEST_JUNIT_REPORT_FILE="${TEST_JUNIT_REPORT_FILE:-junit-e2e-tests.xml}"
 TEST_JUNIT_REPORT_FILE_PATH="${TEST_JUNIT_REPORT_FILE_PATH:-$TEST_OUTPUT_DIR/$TEST_JUNIT_REPORT_FILE}"
 METERING_RUN_DEV_TEST_SETUP="${METERING_RUN_DEV_TEST_SETUP:-false}"
 
-
 mkdir -p "$TEST_OUTPUT_DIR"
 
 echo "\$KUBECONFIG=$KUBECONFIG"
 echo "\$METERING_NAMESPACE=$METERING_NAMESPACE"
 echo "\$METERING_RUN_TESTS_LOCALLY=$METERING_RUN_TESTS_LOCALLY"
 echo "\$METERING_RUN_DEV_TEST_SETUP=$METERING_RUN_DEV_TEST_SETUP"
+echo "\$METERING_REPO_VERSION=$METERING_REPO_VERSION"
 echo "\$METERING_OPERATOR_IMAGE_REPO=$METERING_OPERATOR_IMAGE_REPO"
 echo "\$REPORTING_OPERATOR_IMAGE_REPO=$REPORTING_OPERATOR_IMAGE_REPO"
 echo "\$METERING_OPERATOR_IMAGE_TAG=$METERING_OPERATOR_IMAGE_TAG"
@@ -59,7 +62,7 @@ go test \
     -test.short="${METERING_SHORT_TESTS}" \
     -test.v \
     -parallel 10 \
-    -timeout 60m \
+    -timeout 90m \
     "./test/e2e" \
     -kubeconfig="${KUBECONFIG}" \
     -namespace-prefix="${METERING_NAMESPACE}" \
@@ -67,7 +70,9 @@ go test \
     -log-level="${TEST_LOG_LEVEL}" \
     -run-tests-local="${METERING_RUN_TESTS_LOCALLY}" \
     -repo-path="${METERING_REPO_PATH}" \
+    -repo-version="${METERING_REPO_VERSION}" \
     -run-dev-setup="${METERING_RUN_DEV_TEST_SETUP}" \
+    ${EXTRA_TEST_FLAGS} \
     2>&1 | tee "$TEST_LOG_FILE_PATH" ; TEST_EXIT_CODE=${PIPESTATUS[0]}
 
 # if go-junit-report is installed, create a junit report also
